class Vader::DockerUtil
  require 'socket'
  require 'uri'

  class << self
    def ensure_docker_configured
      # To ensure docker client will work:
      # Check that ENV['DOCKER'] is set and can connect to the DOCKER_HOST.
      # Otherwise, check `boot2docker status`.
      # If b2d isn't running, start it.
      # Get boot2docker ip address and set DOCKER_* env vars.
      return if docker_configured?
      ensure_boot2docker_running
      set_docker_env

    end

    def ensure_boot2docker_running
      if `boot2docker status`.chomp != 'running'
        puts "Starting boot2docker"
        `boot2docker up 2>/dev/null >/dev/null`
        unless $?.success?
          raise "Failed to start boot2docker. Try running 'boot2docker up'"
        end
      end
    end

    def set_docker_env
      puts "Setting boot2docker environment variables"
      `boot2docker shellinit 2>/dev/null`.split("\n").each do |line|
        match = line.match(/(DOCKER\w+)=(.+)\Z/)
        next unless match
        ENV[match[1]] = match[2]
      end
    end

    # Can we open a tcp socket to DOCKER_HOST?
    def docker_configured?
      return false unless ENV['DOCKER_HOST']
      uri = URI.parse(ENV['DOCKER_HOST'])
      TCPSocket.new(uri.host, uri.port).close
      return true
    rescue Errno::ECONNREFUSED
      false
    end
  end

end
